| Package: | GrpString |
| Type: | Package |
| Version: | 0.5.1 |
| Date: | 2026-02-23 |
| License: | GPL-2 |
Some functions have two types, one returning a data frame or a vector and the other exporting
one or more than one .txt file to the current directory. The former is a simple version of the functions,
while the latter can be considered as a generalized or complex version of the former one. This is
because some data sets are large (e.g., many rows or columns), or it helps the users to view and manage
results when more than one data set is exported. Examples of these function pairs are EveStr - EveString,
CommonPatt - CommonPattern, and PatternInfo - UniPatterns.
In addition, to save the users' effort, the function EveString utilizes an input file (which can be a .txt or .csv file) instead of a data frame. This is because the input data are more convenient to be stored in a .txt or .csv file than in a data frame. We suggest the users to copy the relevant input files (including eve1d.txt and eve1d.csv) to a different directory, because the function exports files to the same directory where the input files locate.