StrHclust: Hierarchical cluster of a group of strings

View source: R/StrHclust.R

StrHclustR Documentation

Hierarchical cluster of a group of strings

Description

StrHclust discovers clusters of the strings in a group.

Usage

StrHclust(strings.vec, nclust = 2)

Arguments

strings.vec

String Vector.

nclust

Number of clusters. Default is 2.

Value

Returns a data frame with the specific cluster assigned to each string.

A Hierarchical dendrogram is also exported.

See Also

StrKclust

Examples

# Simple strings
strs3.vec <- c("ABCDdefABCDa", "AC3aABCD", "ACD1AB3", "xYZfgAxZY", "gf56xZYx", "AkfxzYZg")
StrHclust(strs3.vec)


GrpString documentation built on Feb. 24, 2026, 9:06 a.m.