StrKclust: K-means clustering of a group of strings

View source: R/StrKclust.R

StrKclustR Documentation

K-means clustering of a group of strings

Description

StrKclust discovers clusters of the strings in a group.

Usage

StrKclust(strings.vec, nclust = 2, nstart = 1)

Arguments

strings.vec

String Vector.

nclust

Number of clusters. Default is 2.

nstart

Number of random data sets chosen to start. Default is 1.

Value

Returns a data frame with the specific cluster assigned to each string.

A cluster plot is also exported.

See Also

StrHclust

Examples

# Simple strings
strs3.vec <- c("ABCDdefABCDa", "AC3aABCD", "ACD1AB3", "xYZfgAxZY", "gf56xZYx", "AkfxzYZg")
StrKclust(strs3.vec)


GrpString documentation built on Feb. 24, 2026, 9:06 a.m.