TransEntropy: Transition entropy of each string in a group
Description
TransEntropy computes the transition entropy of each of the strings in a group.
Usage
TransEntropy(strings.vec)
Value
Returns a number vector.
Arguments
strings.vec
String Vector.
Details
Entropy is calculated using the Shannon entropy formula: -sum(freqs * log2(freqs)). Here, freqs are transition frequencies, which are the values in the normalized transition matrix exported by function TransMx in this package. The formula is equivalent to the function entropy.empirical in the entropy package when unit is set to log2.
References
I. Hooge; G. Camps. (2013) Scan path entropy and arrow plots: capturing scanning behavior of multiple observers. Frontiers in Psychology.