| event1s.df | R Documentation |
A data frame containing event names, There are 45 rows. Each row has 26 event names.
data(event1s.df)
A data frame with 45 observations or rows.
The event names are from an eye tracking study. Thus, each event name is actually an area of interst (AOI).
data(event1s.df)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.