| StrHclust | R Documentation |
StrHclust discovers clusters of the strings in a group.
StrHclust(strings.vec, nclust = 2)
strings.vec |
String Vector. |
nclust |
Number of clusters. Default is 2. |
Returns a data frame with the specific cluster assigned to each string.
A Hierarchical dendrogram is also exported.
StrKclust
# Simple strings
strs3.vec <- c("ABCDdefABCDa", "AC3aABCD", "ACD1AB3", "xYZfgAxZY", "gf56xZYx", "AkfxzYZg")
StrHclust(strs3.vec)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.