| StrKclust | R Documentation |
StrKclust discovers clusters of the strings in a group.
StrKclust(strings.vec, nclust = 2, nstart = 1)
strings.vec |
String Vector. |
nclust |
Number of clusters. Default is 2. |
nstart |
Number of random data sets chosen to start. Default is 1. |
Returns a data frame with the specific cluster assigned to each string.
A cluster plot is also exported.
StrHclust
# Simple strings
strs3.vec <- c("ABCDdefABCDa", "AC3aABCD", "ACD1AB3", "xYZfgAxZY", "gf56xZYx", "AkfxzYZg")
StrKclust(strs3.vec)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.