TransEntro: Transition entropy of a group of strings
Description
TransEntro computes the overall transition entropy of all the strings in a group.
Usage
TransEntro(strings.vec)
Value
Returns a single number.
Arguments
strings.vec
String Vector.
Details
Entropy is calculated using the Shannon entropy formula: -sum(freqs * log2(freqs)). Here, freqs are transition frequencies, which are the values in the normalized transition matrix exported by function TransMx in this package. The formula is equivalent to the function entropy.empirical in the entropy package when unit is set to log2.
References
I. Hooge; G. Camps. (2013) Scan path entropy and arrow plots: capturing scanning behavior of multiple observers. Frontiers in Psychology.