TransMx: Transition matrices in one group of strings
Description
TransMx discovers transition matrix of a string vector and the related information.
A transition is defined as a substring (in the forward order) with length of 2 characters.
It can be considered as a special common pattern (length of 2).
Usage
TransMx(strings.vec)
Value
The function returns a list, which contains the transition matrix, the normalized matrix, and the sorted numbers of transitions.
Arguments
strings.vec
String Vector.
If a string has fewer than 2 characters, that string will be ignored.