| UniPatterns | R Documentation |
UniPatterns discovers "unique" patterns that are in one group of strings but not the other.
UniPatterns(grp1_pattern, grp2_pattern, grp1_string, grp2_string)
grp1_pattern |
Patterns shared by a certain percent of strings in string group 1. |
grp2_pattern |
Patterns shared by a certain percent of strings in string group 2. |
grp1_string |
String group 1. |
grp2_string |
String group 2. |
A (common) pattern is defined as a substring with the minimum length of three that occurs at least twice among a group of strings.
A unique pattern is a pattern that appears in only one of the two groups of strings.
The function exports a data frame that lists unique patterns: column 1 for string group 1; column 2 for string group 2.
PatternInfo,
CommonPatt,
CommonPattern
data(str1)
data(str2)
data(p1_20up)
data(p2_25up)
UniPatterns(p1_20up, p2_25up, str1, str2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.