powered by
UniPatterns discovers "unique" patterns that are in one group of strings but not the other.
UniPatterns(grp1_pattern, grp2_pattern, grp1_string, grp2_string)
The function exports a data frame that lists unique patterns: column 1 for string group 1; column 2 for string group 2.
Patterns shared by a certain percent of strings in string group 1.
Patterns shared by a certain percent of strings in string group 2.
String group 1.
String group 2.
A (common) pattern is defined as a substring with the minimum length of three that occurs at least twice among a group of strings.
A unique pattern is a pattern that appears in only one of the two groups of strings.
PatternInfo, CommonPatt, CommonPattern
PatternInfo
CommonPatt
CommonPattern
data(str1) data(str2) data(p1_20up) data(p2_25up) UniPatterns(p1_20up, p2_25up, str1, str2)
Run the code above in your browser using DataLab