eventChar.df: Event name - character conversion key
Description
A data frame where each element in column event (event name) corresponds to an element in column char (character),
which can be a letter, digit, or a special character.
Usage
data(eventChar.df)
Arguments
Format
A data frame with 16 observations on the following 2 variables.